@@ -9,32 +9,35 @@
 
 """Draft aware Record Resource Config override."""
 
-from flask_resources.parsers import URLArgsParser
+from flask_resources.parsers import HeadersParser
 from invenio_records_resources.resources import \
     RecordResourceConfig as _RecordResourceConfig
-from invenio_records_resources.resources.records.schemas_url_args import \
-    SearchURLArgsSchema
-from marshmallow import fields, validate
+from invenio_records_resources.resources.records.schemas_links import \
+    SearchLinksSchema
 
 from ..drafts.schemas_links import DraftLinksSchema
 
 
-class DraftSearchURLArgsSchema(SearchURLArgsSchema):
-    """Validate status parameter in addition to normal search parameters."""
-
-    status = fields.Str(
-        validate=validate.OneOf(["published", "draft"]),
-        missing="published",
-    )
-
-
 class RecordResourceConfig(_RecordResourceConfig):
     """Draft aware Record resource config."""
 
-    request_url_args_parser = {
-        "search": URLArgsParser(DraftSearchURLArgsSchema)
-    }
-
     draft_links_config = {
         "record": DraftLinksSchema
     }
+
+
+class RecordVersionsResourceConfig(_RecordResourceConfig):
+    """Record resource version config."""
+
+    list_route = "/records/<pid_value>/versions"
+
+    item_route = "/records/<pid_value>/versions/latest"
+
+    links_config = {
+        "search":  SearchLinksSchema.create(
+            template='/api/records/<pid_value>/versions{?params*}')
+    }
+
+    request_headers_parser = {
+        "search": HeadersParser(None),
+    }
